@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_pages.py 10626 2017-12-10 09:05:41Z Lavender $
+# $Id: create_pages.py 10818 2018-03-05 08:44:31Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
-# $Revision: 10626 $
+# $Date: 2018-03-05 16:44:31 +0800 (週一, 05 三月 2018) $
+# $Revision: 10818 $
 
 import os
 import json
 import traceback
 
+import cms
+
 from django.core.management.base import BaseCommand
 from django.conf import settings
 from django.db import transaction
@@ -79,11 +81,17 @@ class Command(BaseCommand):
                         'index', rootPage, settings.LANGUAGE_CODE, 
                         published=True, meta_description=description)
 
+                    if cms.__version__.startswith('3.5'):
+                        homePage.is_home = True
+                        homePage.save()
+
                     page = homePage.get_public_object()
                     pageTitle1 = Title.objects.get(page=homePage)
                     pageTitle2 = Title.objects.get(page=page)
                     for t in [pageTitle1, pageTitle2]:
                         t.page_title = title
+                        if cms.__version__.startswith('3.5'):
+                            t.path = ''
                         t.save()
 
                     logger.info('Create homepage by %s' % rootPage)
